/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example template project.
* @defgroup nrf_templates_example Example Template
*
*/

#include <stdbool.h>
#include "app_error.h"
#include "nrf_delay.h"
#include "app_util_platform.h"
#include "nrf_drv_gpiote.h"
#include "boards.h"


#define INTERRUPT_PIN   BUTTON_1

void gpiote_evt_handler(nrf_drv_gpiote_pin_t pin, nrf_gpiote_polarity_t action)
{
    switch(action)
    {
        case NRF_GPIOTE_POLARITY_HITOLO:
            nrf_drv_gpiote_out_toggle(LED_2);
            break;
        default:
            //do nothing
            break;
    }
}


/**
 * @brief Function for application main entry.
 */
int main(void)
{
    
    ret_code_t ret_code;
    
    // Initialize the GPIOTE Peripheral 
    ret_code = nrf_drv_gpiote_init();
    APP_ERROR_CHECK(ret_code);
    
    // Configure LED_1 pin as output
    nrf_drv_gpiote_out_config_t led_config = GPIOTE_CONFIG_OUT_TASK_LOW;
    
    // Initialize LED_1 pin as output
    ret_code =  nrf_drv_gpiote_out_init(LED_2, &led_config);
    APP_ERROR_CHECK(ret_code);
    
    // Configuration for Interrupt Pin
    nrf_drv_gpiote_in_config_t config =
    {
        .sense = NRF_GPIOTE_POLARITY_HITOLO,
        .pull = NRF_GPIO_PIN_PULLUP , // NRF_GPIO_PIN_NOPULL
        .is_watcher = false,
        .hi_accuracy = false
    };
        
    // Initialize Interrupt Pin
    ret_code = nrf_drv_gpiote_in_init(INTERRUPT_PIN, &config, gpiote_evt_handler);
    APP_ERROR_CHECK(ret_code);
    
    // Enable Interrupts from interrupt pin
    nrf_drv_gpiote_in_event_enable(INTERRUPT_PIN,true);
    
    
    while (true)
    {
        // Do nothing.
    }
}
/** @} */
